# Redis Proxy for Laravel/Lumen

A simple package to auto-proxy calls on redis to read/write connections for Laravel/Lumen

## Benefits of this package
 - No need to define connections on every call 
 - Centralize read/write connections
 - Failover to default connection when readonly is down

## Setup
### 1. Include package in composer file and update dependencies

```
"require" : {
    ...
    "intergo/redis-proxy" : "^1.0.0"
    ...
}
```

### 2. Configure redis database connections for read/write operations through database config
```
'redis' => [

        'client' => 'phpredis',

        'default' => [
            'host'     => env('REDIS_HOST', '127.0.0.1'),
            'password' => env('REDIS_PASSWORD', null),
            'port'     => env('REDIS_PORT', 6379),
            'database' => 0,
        ],
        'read' => [
            'host'     => env('REDIS_READ_HOST', '127.0.0.1'),
            'password' => env('REDIS_PASSWORD', null),
            'port'     => env('REDIS_READ_PORT', 6379),
            'database' => 0,
        ],
```

### 3. Configure redis cache stores for read/write operations through cache config
```
'stores' => [
    ...
    'redis' => [
            'driver' => 'redis',
            'connection' => 'default',
    ],
    'redis_read' => [
        'driver' => 'redis',
        'connection' => 'read',
    ],
]
```

### 4. Specify how to handle redis connection
Publish config file: `php artisan vendor:publish -tag=laravel-redis-proxy-config`.

For Lumen : `cp vendor/intergo/redis-proxy/config/redis-proxy.php config/redis-proxy.php`.

---------------

<h2> Usage </h2>

A. Inject into constructors
```
    public function __construct(RedisProxy $redis, CacheProxy $cache)
    {
        $this->cache = $cache;
        $this->redis = $redis;
    }
```
B. Use Facades
```
use Intergo\RedisProxy\Facades\RedisProxy as Redis;
use Intergo\RedisProxy\Facades\CacheProxy as Cache; 

    public function example()
    {
        Redis:set('key', 'value');
        $value = Redis::get('key')'
        $this->redis = $redis;
        
        Cache::rememberForever('cache_key', function(){
            return 'code here';
        });
        
        $data = Cache::get('cache_key');
    }
```

## License

The MIT License (MIT). Please see [License File](LICENSE.md) for more information.
